@@ -3,7 +3,7 @@ use utf8;
 use Moo;
 extends 'NewsExtractor::GenericExtractor';
 
-use Importer 'NewsExtractor::TextUtil' => 'normalize_whitespace';
+use Importer 'NewsExtractor::TextUtil' => 'parse_dateline_ymdhms';
 
 sub _build_content_text {
     my ($self) = @_;
@@ -15,15 +15,24 @@ sub _build_content_text {
             && ($_->text =~ m/^★/)
         })->map('remove');
 
+    # Remove recommendations at the end of the article body.
+    $self->dom->at("#contentb div.raw-style > span:nth-child(1)")->following_nodes()->map('remove');
+
     return $self->SUPER::_build_content_text();
 }
 
 sub journalist {
     my ($self) = @_;
     my $guess = $self->dom->at('.fncnews-content > .info > span.small-gray-text') or return;
-    my $text = normalize_whitespace($guess->all_text);
+    my $text = $guess->all_text;
     my ($name) = $text =~ m/(?:東森新聞(?:\s*責任編輯)?)\s+(.+)$/;
     return $name;
 }
 
+sub dateline {
+    my ($self) = @_;
+    my $el = $self->dom->at(".fncnews-content > .info > span.small-gray-text") or return;
+    return parse_dateline_ymdhms($el->all_text(), '+08:00');
+}
+
 1;
