@@ -9,6 +9,7 @@ our @EXPORT = (
     'normalize_whitespace',
     'html2text',
     'is_empty',
+    'parse_dateline_ymdhms',
 );
 
 sub u($) {
@@ -43,4 +44,22 @@ sub html2text {
     return join "\n\n", @paragraphs;
 }
 
+sub parse_dateline_ymdhms {
+    my ($text, $offset) = @_;
+
+    $offset //= '';
+
+    my @t = $text =~ m/([0-9]+)/g;
+    $t[3] //= 23;
+    $t[4] //= 59;
+    $t[5] //= 59;
+
+    return u(
+        sprintf(
+            '%04d-%02d-%02dT%02d:%02d:%02d%s',
+            $t[0], $t[1], $t[2], $t[3], $t[4], $t[5], $offset
+        )
+    );
+}
+
 1;
